@@ -1,11 +1,11 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2017-2024 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2017-2025 Brett Sheffield <bacs@librecast.net> */
 /* librecast/net.h - librecast network API */
 
 #ifndef _LIBRECAST_NET_H
 #define _LIBRECAST_NET_H
 
-#define _GNU_SOURCE
+#define _GNU_SOURCE /* recvmmsg */
 #include <librecast/types.h>
 #include <stdio.h>
 #include <sys/socket.h>
@@ -110,8 +110,9 @@ void lc_ctx_ratelimit(lc_ctx_t *ctx, size_t bps_out, size_t bps_in);
 /* set channel rate limits */
 void lc_channel_ratelimit(lc_channel_t *chan, size_t bps_out, size_t bps_in);
 
-/* set default coding for sockets and channels created with this context */
+/* set/get default coding for sockets and channels created with this context */
 int lc_ctx_coding_set(lc_ctx_t *ctx, int coding);
+int lc_ctx_coding_get(lc_ctx_t *ctx);
 
 /* set symmetric key for context */
 int lc_ctx_getkey(lc_ctx_t *ctx, lc_key_t *key, int type);
@@ -119,11 +120,13 @@ int lc_ctx_setkey(lc_ctx_t *ctx, lc_key_t *key, int type);
 int lc_ctx_set_sym_key(lc_ctx_t *ctx, unsigned char *key, size_t len);
 int lc_ctx_set_pub_key(lc_ctx_t *ctx, unsigned char *key, size_t len);
 
-/* set socket coding */
+/* set/get socket coding */
 int lc_socket_coding_set(lc_socket_t *sock, int coding);
+int lc_socket_coding_get(lc_socket_t *sock);
 
-/* set channel coding */
+/* set/get channel coding */
 int lc_channel_coding_set(lc_channel_t *chan, int coding);
+int lc_channel_coding_get(lc_channel_t *chan);
 
 /* set channel key */
 int lc_channel_setkey(lc_channel_t *chan, lc_key_t *key, int type);
@@ -185,6 +188,10 @@ ssize_t lc_socket_recvmsg(lc_socket_t *sock, struct msghdr *msg, int flags);
 int lc_socket_recvmmsg(lc_socket_t *sock, struct mmsghdr *msgvec, unsigned int vlen,
                 int flags, struct timespec *timeout);
 
+/* socket recv functions which return destination channel in dst */
+ssize_t lc_socket_multi_recv(lc_socket_t *sock, void *buf, size_t len, int flags, lc_channel_t **dst);
+ssize_t lc_socket_multi_recvmsg(lc_socket_t *sock, struct msghdr *msg, int flags, lc_channel_t **dst);
+
 /* send a message to a channel */
 ssize_t lc_msg_send(lc_channel_t *chan, lc_message_t *msg);
 ssize_t lc_msg_sendto(int sock, const void *buf, size_t len, struct sockaddr_in6 *addr, int flags);
@@ -243,8 +250,17 @@ lc_socket_t * lc_socket_by_fd(lc_ctx_t *ctx, int fd);
 
 #ifdef HAVE_LIBLCRQ
 #include <lcrq.h>
+
 /* return lcrq handle */
 rq_t *lc_channel_rq(lc_channel_t *chan);
+
+/* set number of packets of RaptorQ overhead (OH) to send automatically for channel
+ * if unset (default: -1), no automatic sending will occur.
+ * When > 0, functions like lc_channel_send() will automatically send K' + OH
+ * packets in a single call. Returns new value. */
+int lc_ctx_rq_overhead(lc_ctx_t *ctx, int overhead);
+int lc_channel_rq_overhead(lc_channel_t *chan, int overhead);
+
 # if HAVE_RQ_OTI
 int lc_channel_oti_peek(lc_channel_t *chan, rq_oti_t *oti, rq_scheme_t *scheme);
 # endif
@@ -263,6 +279,7 @@ struct in6_addr *lc_channel_in6addr(lc_channel_t *chan);
 unsigned char *lc_channel_get_hash(lc_channel_t *chan);
 
 /* search context and return channel */
+lc_channel_t *lc_socket_channel_by_address(lc_socket_t *sock, struct in6_addr *addr);
 lc_channel_t *lc_channel_by_address(lc_ctx_t *lctx, struct in6_addr *addr);
 lc_channel_t *lc_channel_by_hash(lc_ctx_t *lctx, unsigned char *hash, size_t hashlen);
 
