@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only */
-/* Copyright (c) 2017-2024 Brett Sheffield <bacs@librecast.net> */
+/* Copyright (c) 2017-2025 Brett Sheffield <bacs@librecast.net> */
 
 #ifndef _LIBRECAST_PVT_H
 #define _LIBRECAST_PVT_H 1
@@ -81,6 +81,9 @@ typedef struct lc_ctx_t {
 	int sock; /* AF_LOCAL socket for ioctls */
 	int readers; /* reference count (readers) */
 	int deleted; /* marked for deletion */
+#ifdef HAVE_LIBLCRQ
+	int rq_oh;       /* RaptorQ automatic overhead pkts. Default: -1 (off) */
+#endif
 } lc_ctx_t;
 
 #ifndef IPV6_MULTICAST_ALL
@@ -95,6 +98,7 @@ typedef struct lc_socket_t {
 	lc_socket_t *next;
 	lc_socket_t *pair; /* other socket, if type == LC_SOCK_PAIR */
 	lc_ctx_t *ctx;
+	lc_channel_t *chan_active; /* channel currently in use */
 	lc_router_t *router;
 	unsigned char *oil;
 	lc_socktype_t type;
@@ -110,11 +114,12 @@ typedef struct lc_socket_t {
 #endif
 	int ttl;   /* Time to Live for packets sent from this socket */
 	int bound; /* how many channels are bound to this socket */
-	int ccoding; /* is channel encoding in use on this socket? */
+	int ccoding; /* combined bits of all channel encodings in use on this socket */
 	int status; /* router port status */
 	int sock;
 	int readers; /* reference count (readers) */
 	int deleted; /* marked for deletion */
+	uint16_t T; /* RaptorQ symbol size (bytes) */
 } lc_socket_t;
 
 /* single packet being logged for NACK/replay thread */
@@ -147,6 +152,11 @@ typedef struct lc_channel_gap_detect_t {
 	uint64_t bitmap; /* which of the last 64 packets actually arrived; bit n == next + 64 - n */
 } lc_channel_gap_detect_t;
 
+typedef struct lc_oid_s {
+	unsigned char hash[HASHSIZE];
+	int status;
+} lc_oid_t;
+
 typedef struct lc_channel_t {
 	lc_channel_t *next;
 	lc_ctx_t *ctx;
@@ -165,11 +175,20 @@ typedef struct lc_channel_t {
 	lc_key_t sek; /* secret encryption key */
 	lc_key_t psk; /* public signing key */
 	lc_key_t ssk; /* secret signing key */
+	lc_filter_t *filter; /* channel filter */
+	lc_token_t *token;   /* channel token (sending) */
 	int coding;   /* encryption/encoding to use */
 #ifdef HAVE_LIBLCRQ
 	rq_pid_t pid;
-	rq_t *rq;     /* RaptorQ context */
-	uint16_t T;   /* RaptorQ symbol size (bytes) */
+	rq_t *rq;        /* RaptorQ context */
+	uint32_t *ESI;   /* RaptorQ Encoding Symbol IDs (ESI): 24-bit unsigned integer */
+	uint8_t *rq_blk; /* RaptorQ blocks */
+	uint16_t T;      /* RaptorQ symbol size (bytes) */
+	uint16_t orig;   /* original symbols received */
+	uint16_t syms;   /* symbols received */
+	lc_oid_t oid[2]; /* Object ID */
+	int oid_cur;     /* idx of most recent oid */
+	int rq_oh;       /* RaptorQ automatic overhead pkts. Default: -1 (off) */
 #endif
 	lc_channel_logging_t *logging;
 	lc_channel_gap_detect_t *gap_detect;
